@@ -36,7 +36,7 @@ class resultSet(object):
         return ([int((i - datetime.datetime(1970,1,1)).total_seconds()) \
                 for i in self.timeseries],self.values)
 
-    def plot(self):
+    def plotd(self):
         import matplotlib.pyplot as plt
         import matplotlib.dates as mdates
         fig = plt.figure()
@@ -47,8 +47,28 @@ class resultSet(object):
         ax.xaxis.set_major_formatter(mFormat)
         ax.plot(self.timeseries, self.values)
         return fig
-        #plt.ion()
-        #plt.show()
+
+    def plot(self):
+        import matplotlib.pyplot as plt
+        total = self.hourlyValues
+        a = []
+        for i in range(0,len(self.hourlyValues),24):
+            a.append(self.hourlyValues[i:i+23])
+        data = np.array(a)
+        data = np.rot90(data)
+        fig = plt.figure()
+        ax = fig.add_subplot(111)#plt.subplots()
+        ax.set_xlim([0,365])
+        ax.set_ylim([0,22])
+        ax.set_ylabel('Hour of Day')
+        ax.set_xlabel('Day of Year')
+        heatmap = ax.imshow(data,aspect='auto',cmap=plt.cm.OrRd)
+        txt =  "Year 1 Output: %s KWh" % round(sum(total)/1000,1)
+        cbar = fig.colorbar(heatmap) 
+        cbar.set_label('Output (W)')
+        ax.annotate(txt, xy=(10,3))
+        plt.tight_layout()
+        return fig
 
     def summary(self):
         print "Year 1 Annual Output: %s kWh" % self.annualOutput
@@ -238,14 +258,15 @@ class system(object):
 
         rs.timeseries = dailyTimeseries
         rs.values = dailyInsolation
-        #rs.timeseries = houlyTimeseries
-        #rs.values = hourlyInsolation
+        rs.htimeseries = houlyTimeseries
+        rs.hourlyValues = hourlyInsolation
 
         rs.clippingHours = clip
         rs.dailyAve = (round(totalOutput/365/10)/100)
         rs.annualOutput = (round(totalOutput/10)/100)
 
         return rs
+
     def Pac(self, ins, tCell = 25):
         output = 0
         for i in self.shape:
@@ -333,6 +354,28 @@ class system(object):
             tModule = irradiation.moduleTemp(irradiance, weatherData)
             return self.Pac(irradiance, tModule)
 
+    def virr(self, Pac, timestamp = None, weatherData = None):
+        girr = 1000.
+        gPac =  self.Pac(girr)
+        if Pac > gPac:
+            print "WARNING: Edge effect?"
+        iteration = 2
+        while round(Pac,-1) != round(gPac,-1):
+            #todo: improve non linear search routine
+            tModule = irradiation.moduleTemp(girr, weatherData)
+            gPac =  self.Pac(girr, tModule)
+            if gPac <= Pac:
+                girr = girr + 1000./(iteration**2)
+            else:
+                girr = girr - 1000./(iteration**2)
+            iteration += 1
+            if iteration > 25:
+                raise Exception('too many iterations')
+        solarAz, solarAlt = irradiation.ephemSun(self.place,timestamp)
+        irrRec = irradiation.irrGuess(timestamp,girr, solarAlt, solarAz, self.tilt, self.azimuth)
+        irrRec['girr'] = round(girr,0)
+        return irrRec
+
     def forecastOutput(self, daylightSavings = False, source = None, hours = 24):
     #def powerToday(self, daylightSavings = False, source = None, hours = 24):
         #default is forecast with solpy.blave 
